@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -74,7 +74,7 @@ __all__ = ("DataSyncClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -87,7 +87,7 @@ class Exceptions:
 
 class DataSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html)
     """
 
@@ -103,7 +103,7 @@ class DataSyncClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#can_paginate)
         """
 
@@ -111,7 +111,7 @@ class DataSyncClient(BaseClient):
         """
         Cancels execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#cancel_task_execution)
         """
 
@@ -119,16 +119,16 @@ class DataSyncClient(BaseClient):
         self,
         *,
         ActivationKey: str,
-        AgentName: str = None,
-        Tags: List["TagListEntryTypeDef"] = None,
-        VpcEndpointId: str = None,
-        SubnetArns: List[str] = None,
-        SecurityGroupArns: List[str] = None
+        AgentName: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...,
+        VpcEndpointId: str = ...,
+        SubnetArns: Sequence[str] = ...,
+        SecurityGroupArns: Sequence[str] = ...
     ) -> CreateAgentResponseTypeDef:
         """
         Activates an DataSync agent that you have deployed on your host.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_agent)
         """
 
@@ -137,13 +137,13 @@ class DataSyncClient(BaseClient):
         *,
         EfsFilesystemArn: str,
         Ec2Config: "Ec2ConfigTypeDef",
-        Subdirectory: str = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        Subdirectory: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationEfsResponseTypeDef:
         """
         Creates an endpoint for an Amazon EFS file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_efs)
         """
 
@@ -151,17 +151,17 @@ class DataSyncClient(BaseClient):
         self,
         *,
         FsxFilesystemArn: str,
-        SecurityGroupArns: List[str],
+        SecurityGroupArns: Sequence[str],
         User: str,
         Password: str,
-        Subdirectory: str = None,
-        Tags: List["TagListEntryTypeDef"] = None,
-        Domain: str = None
+        Subdirectory: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...,
+        Domain: str = ...
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
         Creates an endpoint for an Amazon FSx for Windows File Server file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_fsx_windows)
         """
 
@@ -171,14 +171,14 @@ class DataSyncClient(BaseClient):
         Subdirectory: str,
         ServerHostname: str,
         OnPremConfig: "OnPremConfigTypeDef",
-        MountOptions: "NfsMountOptionsTypeDef" = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        MountOptions: "NfsMountOptionsTypeDef" = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationNfsResponseTypeDef:
         """
         Defines a file system on a Network File System (NFS) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_nfs)
         """
 
@@ -187,18 +187,18 @@ class DataSyncClient(BaseClient):
         *,
         ServerHostname: str,
         BucketName: str,
-        AgentArns: List[str],
-        ServerPort: int = None,
-        ServerProtocol: ObjectStorageServerProtocolType = None,
-        Subdirectory: str = None,
-        AccessKey: str = None,
-        SecretKey: str = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        AgentArns: Sequence[str],
+        ServerPort: int = ...,
+        ServerProtocol: ObjectStorageServerProtocolType = ...,
+        Subdirectory: str = ...,
+        AccessKey: str = ...,
+        SecretKey: str = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
         Creates an endpoint for a self-managed object storage bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_object_storage)
         """
 
@@ -207,15 +207,15 @@ class DataSyncClient(BaseClient):
         *,
         S3BucketArn: str,
         S3Config: "S3ConfigTypeDef",
-        Subdirectory: str = None,
-        S3StorageClass: S3StorageClassType = None,
-        AgentArns: List[str] = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        Subdirectory: str = ...,
+        S3StorageClass: S3StorageClassType = ...,
+        AgentArns: Sequence[str] = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationS3ResponseTypeDef:
         """
         Creates an endpoint for an Amazon S3 bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_s3)
         """
 
@@ -226,16 +226,16 @@ class DataSyncClient(BaseClient):
         ServerHostname: str,
         User: str,
         Password: str,
-        AgentArns: List[str],
-        Domain: str = None,
-        MountOptions: "SmbMountOptionsTypeDef" = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        AgentArns: Sequence[str],
+        Domain: str = ...,
+        MountOptions: "SmbMountOptionsTypeDef" = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...
     ) -> CreateLocationSmbResponseTypeDef:
         """
         Defines a file system on a Server Message Block (SMB) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_smb)
         """
 
@@ -244,18 +244,18 @@ class DataSyncClient(BaseClient):
         *,
         SourceLocationArn: str,
         DestinationLocationArn: str,
-        CloudWatchLogGroupArn: str = None,
-        Name: str = None,
-        Options: "OptionsTypeDef" = None,
-        Excludes: List["FilterRuleTypeDef"] = None,
-        Schedule: "TaskScheduleTypeDef" = None,
-        Tags: List["TagListEntryTypeDef"] = None,
-        Includes: List["FilterRuleTypeDef"] = None
+        CloudWatchLogGroupArn: str = ...,
+        Name: str = ...,
+        Options: "OptionsTypeDef" = ...,
+        Excludes: Sequence["FilterRuleTypeDef"] = ...,
+        Schedule: "TaskScheduleTypeDef" = ...,
+        Tags: Sequence["TagListEntryTypeDef"] = ...,
+        Includes: Sequence["FilterRuleTypeDef"] = ...
     ) -> CreateTaskResponseTypeDef:
         """
         Creates a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.create_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.create_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_task)
         """
 
@@ -263,7 +263,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.delete_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_agent)
         """
 
@@ -271,7 +271,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes the configuration of a location used by DataSync.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.delete_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_location)
         """
 
@@ -279,7 +279,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.delete_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_task)
         """
 
@@ -288,7 +288,7 @@ class DataSyncClient(BaseClient):
         Returns metadata such as the name, the network interfaces, and the status (that
         is, whether the agent is running or not) for an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_agent)
         """
 
@@ -296,7 +296,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information about an Amazon EFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_efs)
         """
 
@@ -307,7 +307,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path information about an Amazon FSx for Windows
         File Server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_fsx_windows)
         """
 
@@ -315,7 +315,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information, about an NFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_nfs)
         """
 
@@ -325,7 +325,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a self-managed object storage server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_object_storage)
         """
 
@@ -333,7 +333,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as bucket name, about an Amazon S3 bucket location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_s3)
         """
 
@@ -341,7 +341,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path and user information about an SMB location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_smb)
         """
 
@@ -349,7 +349,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task)
         """
 
@@ -359,80 +359,80 @@ class DataSyncClient(BaseClient):
         """
         Returns detailed metadata about a task that is being executed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task_execution)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#generate_presigned_url)
         """
 
     def list_agents(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAgentsResponseTypeDef:
         """
         Returns a list of agents owned by an Amazon Web Services account in the Amazon
         Web Services Region specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.list_agents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_agents)
         """
 
     def list_locations(
         self,
         *,
-        MaxResults: int = None,
-        NextToken: str = None,
-        Filters: List["LocationFilterTypeDef"] = None
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        Filters: Sequence["LocationFilterTypeDef"] = ...
     ) -> ListLocationsResponseTypeDef:
         """
         Returns a list of source and destination locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.list_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_locations)
         """
 
     def list_tags_for_resource(
-        self, *, ResourceArn: str, MaxResults: int = None, NextToken: str = None
+        self, *, ResourceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListTagsForResourceResponseTypeDef:
         """
         Returns all the tags associated with a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tags_for_resource)
         """
 
     def list_task_executions(
-        self, *, TaskArn: str = None, MaxResults: int = None, NextToken: str = None
+        self, *, TaskArn: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> ListTaskExecutionsResponseTypeDef:
         """
         Returns a list of executed tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.list_task_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_task_executions)
         """
 
     def list_tasks(
         self,
         *,
-        MaxResults: int = None,
-        NextToken: str = None,
-        Filters: List["TaskFilterTypeDef"] = None
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        Filters: Sequence["TaskFilterTypeDef"] = ...
     ) -> ListTasksResponseTypeDef:
         """
         Returns a list of all the tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.list_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tasks)
         """
 
@@ -440,40 +440,40 @@ class DataSyncClient(BaseClient):
         self,
         *,
         TaskArn: str,
-        OverrideOptions: "OptionsTypeDef" = None,
-        Includes: List["FilterRuleTypeDef"] = None,
-        Excludes: List["FilterRuleTypeDef"] = None
+        OverrideOptions: "OptionsTypeDef" = ...,
+        Includes: Sequence["FilterRuleTypeDef"] = ...,
+        Excludes: Sequence["FilterRuleTypeDef"] = ...
     ) -> StartTaskExecutionResponseTypeDef:
         """
         Starts a specific invocation of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.start_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#start_task_execution)
         """
 
     def tag_resource(
-        self, *, ResourceArn: str, Tags: List["TagListEntryTypeDef"]
+        self, *, ResourceArn: str, Tags: Sequence["TagListEntryTypeDef"]
     ) -> Dict[str, Any]:
         """
         Applies a key-value pair to an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, Keys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes a tag from an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#untag_resource)
         """
 
-    def update_agent(self, *, AgentArn: str, Name: str = None) -> Dict[str, Any]:
+    def update_agent(self, *, AgentArn: str, Name: str = ...) -> Dict[str, Any]:
         """
         Updates the name of an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_agent)
         """
 
@@ -481,15 +481,15 @@ class DataSyncClient(BaseClient):
         self,
         *,
         LocationArn: str,
-        Subdirectory: str = None,
-        OnPremConfig: "OnPremConfigTypeDef" = None,
-        MountOptions: "NfsMountOptionsTypeDef" = None
+        Subdirectory: str = ...,
+        OnPremConfig: "OnPremConfigTypeDef" = ...,
+        MountOptions: "NfsMountOptionsTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Updates some of the parameters of a previously created location for Network File
         System (NFS) access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_nfs)
         """
 
@@ -497,18 +497,18 @@ class DataSyncClient(BaseClient):
         self,
         *,
         LocationArn: str,
-        ServerPort: int = None,
-        ServerProtocol: ObjectStorageServerProtocolType = None,
-        Subdirectory: str = None,
-        AccessKey: str = None,
-        SecretKey: str = None,
-        AgentArns: List[str] = None
+        ServerPort: int = ...,
+        ServerProtocol: ObjectStorageServerProtocolType = ...,
+        Subdirectory: str = ...,
+        AccessKey: str = ...,
+        SecretKey: str = ...,
+        AgentArns: Sequence[str] = ...
     ) -> Dict[str, Any]:
         """
         Updates some of the parameters of a previously created location for self-managed
         object storage server access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_object_storage)
         """
 
@@ -516,18 +516,18 @@ class DataSyncClient(BaseClient):
         self,
         *,
         LocationArn: str,
-        Subdirectory: str = None,
-        User: str = None,
-        Domain: str = None,
-        Password: str = None,
-        AgentArns: List[str] = None,
-        MountOptions: "SmbMountOptionsTypeDef" = None
+        Subdirectory: str = ...,
+        User: str = ...,
+        Domain: str = ...,
+        Password: str = ...,
+        AgentArns: Sequence[str] = ...,
+        MountOptions: "SmbMountOptionsTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Updates some of the parameters of a previously created location for Server
         Message Block (SMB) file system access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_smb)
         """
 
@@ -535,17 +535,17 @@ class DataSyncClient(BaseClient):
         self,
         *,
         TaskArn: str,
-        Options: "OptionsTypeDef" = None,
-        Excludes: List["FilterRuleTypeDef"] = None,
-        Schedule: "TaskScheduleTypeDef" = None,
-        Name: str = None,
-        CloudWatchLogGroupArn: str = None,
-        Includes: List["FilterRuleTypeDef"] = None
+        Options: "OptionsTypeDef" = ...,
+        Excludes: Sequence["FilterRuleTypeDef"] = ...,
+        Schedule: "TaskScheduleTypeDef" = ...,
+        Name: str = ...,
+        CloudWatchLogGroupArn: str = ...,
+        Includes: Sequence["FilterRuleTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Updates the metadata associated with a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task)
         """
 
@@ -555,21 +555,21 @@ class DataSyncClient(BaseClient):
         """
         Updates execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Client.update_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Paginator.ListAgents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Paginator.ListLocations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
         """
 
@@ -578,7 +578,7 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
         """
 
@@ -587,13 +587,13 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/datasync.html#DataSync.Paginator.ListTasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
         """
