@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     AgentStatusType,
@@ -160,10 +160,10 @@ _OptionalCreateAgentRequestRequestTypeDef = TypedDict(
     "_OptionalCreateAgentRequestRequestTypeDef",
     {
         "AgentName": str,
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
         "VpcEndpointId": str,
-        "SubnetArns": List[str],
-        "SecurityGroupArns": List[str],
+        "SubnetArns": Sequence[str],
+        "SecurityGroupArns": Sequence[str],
     },
     total=False,
 )
@@ -194,7 +194,7 @@ _OptionalCreateLocationEfsRequestRequestTypeDef = TypedDict(
     "_OptionalCreateLocationEfsRequestRequestTypeDef",
     {
         "Subdirectory": str,
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
 )
@@ -218,7 +218,7 @@ _RequiredCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
     "_RequiredCreateLocationFsxWindowsRequestRequestTypeDef",
     {
         "FsxFilesystemArn": str,
-        "SecurityGroupArns": List[str],
+        "SecurityGroupArns": Sequence[str],
         "User": str,
         "Password": str,
     },
@@ -227,7 +227,7 @@ _OptionalCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
     "_OptionalCreateLocationFsxWindowsRequestRequestTypeDef",
     {
         "Subdirectory": str,
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
         "Domain": str,
     },
     total=False,
@@ -261,7 +261,7 @@ _OptionalCreateLocationNfsRequestRequestTypeDef = TypedDict(
     "_OptionalCreateLocationNfsRequestRequestTypeDef",
     {
         "MountOptions": "NfsMountOptionsTypeDef",
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
 )
@@ -286,7 +286,7 @@ _RequiredCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
     {
         "ServerHostname": str,
         "BucketName": str,
-        "AgentArns": List[str],
+        "AgentArns": Sequence[str],
     },
 )
 _OptionalCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
@@ -297,7 +297,7 @@ _OptionalCreateLocationObjectStorageRequestRequestTypeDef = TypedDict(
         "Subdirectory": str,
         "AccessKey": str,
         "SecretKey": str,
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
 )
@@ -330,8 +330,8 @@ _OptionalCreateLocationS3RequestRequestTypeDef = TypedDict(
     {
         "Subdirectory": str,
         "S3StorageClass": S3StorageClassType,
-        "AgentArns": List[str],
-        "Tags": List["TagListEntryTypeDef"],
+        "AgentArns": Sequence[str],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
 )
@@ -358,7 +358,7 @@ _RequiredCreateLocationSmbRequestRequestTypeDef = TypedDict(
         "ServerHostname": str,
         "User": str,
         "Password": str,
-        "AgentArns": List[str],
+        "AgentArns": Sequence[str],
     },
 )
 _OptionalCreateLocationSmbRequestRequestTypeDef = TypedDict(
@@ -366,7 +366,7 @@ _OptionalCreateLocationSmbRequestRequestTypeDef = TypedDict(
     {
         "Domain": str,
         "MountOptions": "SmbMountOptionsTypeDef",
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
 )
@@ -399,10 +399,10 @@ _OptionalCreateTaskRequestRequestTypeDef = TypedDict(
         "CloudWatchLogGroupArn": str,
         "Name": str,
         "Options": "OptionsTypeDef",
-        "Excludes": List["FilterRuleTypeDef"],
+        "Excludes": Sequence["FilterRuleTypeDef"],
         "Schedule": "TaskScheduleTypeDef",
-        "Tags": List["TagListEntryTypeDef"],
-        "Includes": List["FilterRuleTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
+        "Includes": Sequence["FilterRuleTypeDef"],
     },
     total=False,
 )
@@ -643,7 +643,7 @@ Ec2ConfigTypeDef = TypedDict(
     "Ec2ConfigTypeDef",
     {
         "SubnetArn": str,
-        "SecurityGroupArns": List[str],
+        "SecurityGroupArns": Sequence[str],
     },
 )
 
@@ -679,7 +679,7 @@ ListLocationsRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["LocationFilterTypeDef"],
+        "Filters": Sequence["LocationFilterTypeDef"],
     },
     total=False,
 )
@@ -749,7 +749,7 @@ ListTasksRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
-        "Filters": List["TaskFilterTypeDef"],
+        "Filters": Sequence["TaskFilterTypeDef"],
     },
     total=False,
 )
@@ -767,7 +767,7 @@ LocationFilterTypeDef = TypedDict(
     "LocationFilterTypeDef",
     {
         "Name": LocationFilterNameType,
-        "Values": List[str],
+        "Values": Sequence[str],
         "Operator": OperatorType,
     },
 )
@@ -792,7 +792,7 @@ NfsMountOptionsTypeDef = TypedDict(
 OnPremConfigTypeDef = TypedDict(
     "OnPremConfigTypeDef",
     {
-        "AgentArns": List[str],
+        "AgentArns": Sequence[str],
     },
 )
 
@@ -874,8 +874,8 @@ _OptionalStartTaskExecutionRequestRequestTypeDef = TypedDict(
     "_OptionalStartTaskExecutionRequestRequestTypeDef",
     {
         "OverrideOptions": "OptionsTypeDef",
-        "Includes": List["FilterRuleTypeDef"],
-        "Excludes": List["FilterRuleTypeDef"],
+        "Includes": Sequence["FilterRuleTypeDef"],
+        "Excludes": Sequence["FilterRuleTypeDef"],
     },
     total=False,
 )
@@ -919,7 +919,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagListEntryTypeDef"],
+        "Tags": Sequence["TagListEntryTypeDef"],
     },
 )
 
@@ -952,7 +952,7 @@ TaskFilterTypeDef = TypedDict(
     "TaskFilterTypeDef",
     {
         "Name": TaskFilterNameType,
-        "Values": List[str],
+        "Values": Sequence[str],
         "Operator": OperatorType,
     },
 )
@@ -978,7 +978,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Keys": List[str],
+        "Keys": Sequence[str],
     },
 )
 
@@ -1040,7 +1040,7 @@ _OptionalUpdateLocationObjectStorageRequestRequestTypeDef = TypedDict(
         "Subdirectory": str,
         "AccessKey": str,
         "SecretKey": str,
-        "AgentArns": List[str],
+        "AgentArns": Sequence[str],
     },
     total=False,
 )
@@ -1066,7 +1066,7 @@ _OptionalUpdateLocationSmbRequestRequestTypeDef = TypedDict(
         "User": str,
         "Domain": str,
         "Password": str,
-        "AgentArns": List[str],
+        "AgentArns": Sequence[str],
         "MountOptions": "SmbMountOptionsTypeDef",
     },
     total=False,
@@ -1097,11 +1097,11 @@ _OptionalUpdateTaskRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateTaskRequestRequestTypeDef",
     {
         "Options": "OptionsTypeDef",
-        "Excludes": List["FilterRuleTypeDef"],
+        "Excludes": Sequence["FilterRuleTypeDef"],
         "Schedule": "TaskScheduleTypeDef",
         "Name": str,
         "CloudWatchLogGroupArn": str,
-        "Includes": List["FilterRuleTypeDef"],
+        "Includes": Sequence["FilterRuleTypeDef"],
     },
     total=False,
 )
